@@ -440,7 +440,7 @@ class GtkLoadGameDialog:
 
             fileName = self.__gui.get_widget('filechooserwidget').get_filename()
             if fileName is None:
-                return #error = _('Please select a file to load')
+                error = _('Please select a file to load')
             else:
                 error = self.__mainUI.feedback.loadGame(fileName, responseId == gtk.RESPONSE_YES)
 
