@@ -41,6 +41,7 @@
 #include <dirent.h>
 #include <string.h>
 #include <math.h>
+#include <ctype.h>
 
 int LINES = 20;
 int COLUMNS = 14;
@@ -91,15 +92,14 @@ Tetris::Tetris(int cmdlLevel):
 	GtkWidget *vbox;
 	GtkWidget *aspect_frame;
 	GtkWidget *menubar;
-	gint width, height;
 
 	gchar *outdir;
-	const GtkTargetEntry targets[] = {{"text/uri-list", 0, URI_LIST}, 
-					  {"property/bgimage", 0, URI_LIST},
-					  {"text/plain", 0, TEXT_PLAIN},
-					  {"STRING", 0, TEXT_PLAIN},
-					  {"application/x-color", 0, COLOUR},
-					  {"x-special/gnome-reset-background", 0, RESET}};
+	const GtkTargetEntry targets[] = {{(gchar*) "text/uri-list", 0, URI_LIST}, 
+					  {(gchar*) "property/bgimage", 0, URI_LIST},
+					  {(gchar*) "text/plain", 0, TEXT_PLAIN},
+					  {(gchar*) "STRING", 0, TEXT_PLAIN},
+					  {(gchar*) "application/x-color", 0, COLOUR},
+					  {(gchar*) "x-special/gnome-reset-background", 0, RESET}};
 
 	const GtkActionEntry actions[] = {
 	{ "GameMenu", NULL, N_("_Game") },
@@ -499,7 +499,6 @@ Tetris::setOptions ()
 void
 Tetris::setSound (GtkWidget *widget, gpointer data)
 {
-	Tetris *t = (Tetris*)data;
         games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_SOUND,
 			        GTK_TOGGLE_BUTTON (widget)->active);
 }
@@ -507,7 +506,6 @@ Tetris::setSound (GtkWidget *widget, gpointer data)
 void 
 Tetris::setSelectionPreview(GtkWidget *widget, void *d)
 {
-	Tetris *t = (Tetris*) d;
         games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_DO_PREVIEW,
 			        GTK_TOGGLE_BUTTON (widget)->active);
 }
@@ -515,7 +513,6 @@ Tetris::setSelectionPreview(GtkWidget *widget, void *d)
 void 
 Tetris::setSelectionBlocks(GtkWidget *widget, void *d)
 {
-	Tetris *t = (Tetris*) d;
         games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_RANDOM_BLOCK_COLORS,
 			        GTK_TOGGLE_BUTTON (widget)->active);
 }
@@ -523,7 +520,6 @@ Tetris::setSelectionBlocks(GtkWidget *widget, void *d)
 void 
 Tetris::setRotateCounterClockWise(GtkWidget *widget, void *d)
 {
-	Tetris *t = (Tetris*) d;
         games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_ROTATE_COUNTER_CLOCKWISE,
 			        GTK_TOGGLE_BUTTON (widget)->active);
 }
@@ -532,8 +528,6 @@ void
 Tetris::setSelection(GtkWidget *widget, void *data)
 {
 	Tetris *t;
-	GList * item;
-
       	t = (Tetris *)data;
 
 	t->themeno = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
@@ -558,7 +552,6 @@ Tetris::setTarget (GtkWidget *widget, void *data)
 void
 Tetris::lineFillHeightChanged (GtkWidget *spin, gpointer data)
 {
-	Tetris *t = (Tetris *)data;
 	gint value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
         games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_LINE_FILL_HEIGHT, value);
 }
@@ -566,7 +559,6 @@ Tetris::lineFillHeightChanged (GtkWidget *spin, gpointer data)
 void
 Tetris::lineFillProbChanged (GtkWidget *spin, gpointer data)
 {
-	Tetris *t = (Tetris *)data;
 	gint value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
         games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_LINE_FILL_PROBABILITY, value);
 }
@@ -574,7 +566,6 @@ Tetris::lineFillProbChanged (GtkWidget *spin, gpointer data)
 void
 Tetris::startingLevelChanged (GtkWidget *spin, gpointer data)
 {
-	Tetris *t = (Tetris *)data;
 	gint value = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
         games_conf_set_integer (KEY_OPTIONS_GROUP, KEY_STARTING_LEVEL, value);
 }
@@ -987,9 +978,9 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 	if (t->timeoutId == 0)
 		return FALSE;
 
-	keyval = ((GdkEventKey*)event)->keyval;
+	keyval = toupper(((GdkEventKey*)event)->keyval);
 
-	if (keyval == t->movePause)
+	if (keyval == toupper(t->movePause))
 	{
 		t->togglePause();
 		return TRUE;
@@ -998,29 +989,29 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 	if (t->paused)
 		return FALSE;
 
-	if (keyval == t->moveLeft) {
+	if (keyval == toupper(t->moveLeft)) {
 		res = t->field->moveBlockLeft();
 		if (res)
 			games_sound_play ("slide");
 		t->onePause = false;
-	} else if (keyval == t->moveRight) {
+	} else if (keyval == toupper(t->moveRight)) {
 		res = t->field->moveBlockRight();
 		if (res)
 			games_sound_play ("slide");
 		t->onePause = false;
-	} else if (keyval == t->moveRotate) {
+	} else if (keyval == toupper(t->moveRotate)) {
 		res = t->field->rotateBlock(rotateCounterClockWise);
 		if (res)
 			games_sound_play ("turn");
 		t->onePause = false;
-	} else if (keyval == t->moveDown) {
+	} else if (keyval == toupper(t->moveDown)) {
 		if (!t->fastFall && !t->onePause) {
 			t->fastFall = true;
 			g_source_remove (t->timeoutId);
 			t->timeoutId = g_timeout_add (10, timeoutHandler, t);
 			res = true;
 		}
-	} else if (keyval == t->moveDrop) {
+	} else if (keyval == toupper(t->moveDrop)) {
 		if (!t->dropBlock) {
 			t->dropBlock = true;
 			t->field->dropBlock();
@@ -1371,8 +1362,6 @@ Tetris::gameNew(GtkAction *action, void *d)
 int
 Tetris::gameHelp(GtkAction *action, void *d)
 {
-	Tetris *t = (Tetris*) d;
-
 	gnome_help_display ("gnometris.xml", NULL, NULL);
 
 	return TRUE;
